@@ -683,11 +683,18 @@ var cmdCloseTab =
                              L10NUtils.getString("DontCloseTab"),
                              L10NUtils.getString("NoDiscardChanges"));
        switch(rv) {
-         case 1: return rv;
-         case 0: if (!cmdSave.doCommand()) return rv;
+         case 1:
+           SaveCurrentTabLocation();
+           return rv;
+         case 0:
+           if (!cmdSave.doCommand()) {
+             SaveCurrentTabLocation();
+             return rv;
+           }
          default: break;
        }
     }
+    SaveCurrentTabLocation();
     doCloseTab(EditorUtils.getCurrentTabEditor().selectedTab);
     return rv;
   }
@@ -2487,5 +2494,5 @@ var bgSelectTableColumnCommand =
 };
 
 
-//@line 504 "/home/glazou/trees/bg1/bluegriffon/base/content/bluegriffon/js/commands.js"
+//@line 504 "/home/glazou/trees/OFFICIAL_1.0/bluegriffon/base/content/bluegriffon/js/commands.js"
 
